# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/paging/v1alpha/paging_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x12\x1estrmprivacy.api.paging.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\"\xe4\x01\n\x08PageInfo\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12&\n\x0c\x63urrent_page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x0b\x63urrentPage\x12%\n\x0erequested_page\x18\x04 \x01(\x05R\rrequestedPage\x12$\n\x0btotal_pages\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03R\ntotalPages\x12\"\n\npage_token\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tpageTokenBm\n!io.strmprivacy.api.paging.v1alphaP\x01ZFgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1alpha;pagingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.paging.v1alpha.paging_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.paging.v1alphaP\001ZFgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1alpha;paging'
  _PAGEINFO.fields_by_name['total_size']._options = None
  _PAGEINFO.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['current_page']._options = None
  _PAGEINFO.fields_by_name['current_page']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['total_pages']._options = None
  _PAGEINFO.fields_by_name['total_pages']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['page_token']._options = None
  _PAGEINFO.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _PAGEINFO._serialized_start=121
  _PAGEINFO._serialized_end=349
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.forms.v1alpha import forms_v1alpha_pb2 as strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2


class FormsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFormTemplates = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/ListFormTemplates',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.FromString,
                )
        self.GetFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/GetFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.FromString,
                )
        self.UpsertFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/UpsertFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.FromString,
                )
        self.DeleteFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/DeleteFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.FromString,
                )


class FormsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFormTemplates(self, request, context):
        """CRUD on Form Templates
        returns all the form templates for the organization of the caller.
        currently also includes the hard-coded templates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FormsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFormTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFormTemplates,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.SerializeToString,
            ),
            'GetFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.SerializeToString,
            ),
            'UpsertFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.SerializeToString,
            ),
            'DeleteFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.forms.v1alpha.FormsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FormsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFormTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/ListFormTemplates',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/GetFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/UpsertFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/DeleteFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.project_plans.v1alpha import project_plans_v1alpha_pb2 as strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2


class ProjectPlansServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListProjectPlans = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/ListProjectPlans',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.FromString,
                )
        self.GetProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/GetProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.FromString,
                )
        self.UpsertProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/UpsertProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.FromString,
                )
        self.DeleteProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/DeleteProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.FromString,
                )
        self.BuildProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.FromString,
                )
        self.BuildProjectPlanFromTemplateIds = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlanFromTemplateIds',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.FromString,
                )


class ProjectPlansServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListProjectPlans(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuildProjectPlan(self, request, context):
        """builds an empty (not filled-in) project plan from a template and store it in the database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuildProjectPlanFromTemplateIds(self, request, context):
        """builds an empty (not filled-in) project plan from a template and store it in the database.
        (-- api-linter: core::0136::prepositions=disabled
        aip.dev/not-precedent: We need to do this because the name makes sense. --)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectPlansServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListProjectPlans': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectPlans,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.SerializeToString,
            ),
            'GetProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.SerializeToString,
            ),
            'UpsertProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.SerializeToString,
            ),
            'DeleteProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.SerializeToString,
            ),
            'BuildProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.SerializeToString,
            ),
            'BuildProjectPlanFromTemplateIds': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildProjectPlanFromTemplateIds,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.project_plans.v1alpha.ProjectPlansService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectPlansService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListProjectPlans(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/ListProjectPlans',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/GetProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/UpsertProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/DeleteProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BuildProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BuildProjectPlanFromTemplateIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlanFromTemplateIds',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.notifications.v1 import notifications_v1_pb2 as strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2


class NotificationsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubscribeNotifications = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/SubscribeNotifications',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsResponse.FromString,
                )
        self.UnSubscribeNotifications = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/UnSubscribeNotifications',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsResponse.FromString,
                )
        self.ListSubscriptions = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/ListSubscriptions',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsResponse.FromString,
                )
        self.NotifySubscribers = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/NotifySubscribers',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersResponse.FromString,
                )
        self.NotifyUsers = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/NotifyUsers',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersResponse.FromString,
                )
        self.ReceiveNotifications = channel.unary_stream(
                '/strmprivacy.api.notifications.v1.NotificationsService/ReceiveNotifications',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsResponse.FromString,
                )
        self.ListNotifications = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/ListNotifications',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsResponse.FromString,
                )
        self.AlterNotificationsHasBeenSeen = channel.unary_unary(
                '/strmprivacy.api.notifications.v1.NotificationsService/AlterNotificationsHasBeenSeen',
                request_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenResponse.FromString,
                )


class NotificationsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SubscribeNotifications(self, request, context):
        """Tell the notification service that the given user should receive notifications about the given entity.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnSubscribeNotifications(self, request, context):
        """Tell the notification service that the given user should *not* receive notifications about the given entity.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSubscriptions(self, request, context):
        """List the subscriptions of a certain user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NotifySubscribers(self, request, context):
        """Called by systems (schema-registry for instance) that want to notify subscribed users about something.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NotifyUsers(self, request, context):
        """Notify specific users directly, regardless of their subscriptions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceiveNotifications(self, request, context):
        """Called by the user's browser to receive notifications.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNotifications(self, request, context):
        """List notifications for a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlterNotificationsHasBeenSeen(self, request, context):
        """set the has_been_seen status of notification(s)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SubscribeNotifications': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeNotifications,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsResponse.SerializeToString,
            ),
            'UnSubscribeNotifications': grpc.unary_unary_rpc_method_handler(
                    servicer.UnSubscribeNotifications,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsResponse.SerializeToString,
            ),
            'ListSubscriptions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSubscriptions,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsResponse.SerializeToString,
            ),
            'NotifySubscribers': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifySubscribers,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersResponse.SerializeToString,
            ),
            'NotifyUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifyUsers,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersResponse.SerializeToString,
            ),
            'ReceiveNotifications': grpc.unary_stream_rpc_method_handler(
                    servicer.ReceiveNotifications,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsResponse.SerializeToString,
            ),
            'ListNotifications': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotifications,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsResponse.SerializeToString,
            ),
            'AlterNotificationsHasBeenSeen': grpc.unary_unary_rpc_method_handler(
                    servicer.AlterNotificationsHasBeenSeen,
                    request_deserializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.notifications.v1.NotificationsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotificationsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SubscribeNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/SubscribeNotifications',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.SubscribeNotificationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnSubscribeNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/UnSubscribeNotifications',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.UnSubscribeNotificationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSubscriptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/ListSubscriptions',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListSubscriptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NotifySubscribers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/NotifySubscribers',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifySubscribersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NotifyUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/NotifyUsers',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.NotifyUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReceiveNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/ReceiveNotifications',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ReceiveNotificationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/ListNotifications',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.ListNotificationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlterNotificationsHasBeenSeen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.notifications.v1.NotificationsService/AlterNotificationsHasBeenSeen',
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenRequest.SerializeToString,
            strmprivacy_dot_api_dot_notifications_dot_v1_dot_notifications__v1__pb2.AlterNotificationsHasBeenSeenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
